@@ -33,7 +33,7 @@ class Ticket(AnyEntity):
     # dublin core #############################################################
 
     def dc_title(self):
-        return u'#%s: %s' % (self.eid, self.title)
+        return u'#%s %s' % (self.eid, self.title)
 
     def dc_long_title(self):
         return u'%s %s' % (self.project.name, self.dc_title())
