@@ -45,7 +45,7 @@ url: %(url)s
 """)
 
     def _subject(self, entity):
-        return self._cw._(u'%(etype)s "%(title)s" updated') % {
+        return self._cw._(u'%(etype)s updated: %(title)s') % {
             'etype': entity.dc_type(), 'title': entity.dc_title()}
 
 
@@ -104,7 +104,7 @@ class TicketStatusChangeView(StatusChangeMixIn, TrackerEmailView):
     __select__ = is_instance('Ticket')
 
     def _subject(self, entity):
-        return self._cw._(u'%(etype)s "%(title)s" is now in state "%(state)s"') % {
+        return self._cw._(u'%(etype)s %(state)s: %(title)s') % {
             'etype': entity.dc_type(), 'title': entity.dc_title(),
             'state': self._cw.__(self._kwargs['current_state'])}
 
@@ -182,5 +182,5 @@ URL
         return ctx
 
     def _subject(self, entity):
-        return '%s %s' % (self._cw.__('New %s' % entity.e_schema),
-                          entity.dc_title())
+        return self._cw._('%(etype)s added: %(title)s') % {
+            'etype': str(entity.e_schema).lower(), 'title': entity.dc_title()}
