@@ -1,7 +1,7 @@
 """views for Ticket entities
 
 :organization: Logilab
-:copyright: 2006-2010 LOGILAB S.A. (Paris, FRANCE), license is LGPL.
+:copyright: 2006-2011 LOGILAB S.A. (Paris, FRANCE), license is LGPL.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -47,6 +47,9 @@ class TicketPrimaryView(primary.PrimaryView):
 
 # pluggable sections ###########################################################
 
+_pvs.tag_object_of(('*', 'identical_to', 'Ticket'), 'hidden')
+_pvs.tag_subject_of(('Ticket', 'identical_to', '*'), 'hidden')
+
 class TicketIdenticalToVComponent(component.RelatedObjectsVComponent):
     """display identical tickets"""
     __regid__ = 'tickectidentical'
