@@ -66,10 +66,13 @@ class VersionPrimaryTab(tabs.PrimaryTab):
             self.wview(vid, entity.related('conflicts'))
             self.w(u'</ul></div>')
         rset = self._cw.execute(*attr_tuple(entity, 'tickets_rql'))
-        nbcol = entity.tickets_rql_nb_displayed_cols
-        self._cw.view('table', rset, 'noresult', subvid='incontext',
-                      displaycols=range(nbcol), displayfilter=1,
-                      displayactions=1, w=self.w)
+        if rset:
+            nbcol = entity.tickets_rql_nb_displayed_cols
+            self._cw.view('table', rset, subvid='incontext',
+                          displaycols=range(nbcol), displayfilter=1,
+                          displayactions=1, w=self.w)
+        else:
+            self.w(u'<p>%s</p>') % self._cw._('There is no ticket in this version.')
         super(VersionPrimaryTab, self).render_entity_relations(entity)
 
 
